==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGroupingExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebGroupingExpressionDescription } from "./WebGroupingExpressionDescription";
/**
 * @hidden
 */
export let WebGroupingExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupingExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupingExpressionDescriptionMetadata.a == null) {
                WebGroupingExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupingExpressionDescriptionMetadata.c(WebGroupingExpressionDescriptionMetadata.a);
            }
            if (a.j(WebGroupingExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGroupingExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WebSortingExpressionDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GroupingExpression");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebGroupingExpressionDescriptionMetadata.b(a);
            a.aa("WebGroupingExpression", () => new WebGroupingExpressionDescription());
            a.z("WebGroupingExpression", WebGroupingExpressionDescriptionMetadata.a);
        }
    }
    WebGroupingExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupingExpressionDescriptionMetadata, 'WebGroupingExpressionDescriptionMetadata');
    WebGroupingExpressionDescriptionMetadata.a = null;
    return WebGroupingExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGroupingExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingExpressionDescriptionMetadata } from "./WebSortingExpressionDescriptionMetadata";
import { WebGroupingExpressionDescription } from "./WebGroupingExpressionDescription";
/**
 * @hidden
 */
export let WebGroupingExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupingExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupingExpressionDescriptionMetadata.a == null) {
                WebGroupingExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupingExpressionDescriptionMetadata.c(WebGroupingExpressionDescriptionMetadata.a);
            }
            if (a.k(WebGroupingExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGroupingExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WebSortingExpressionDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GroupingExpression");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebGroupingExpressionDescriptionMetadata.b(a);
            a.ac("WebGroupingExpression", () => new WebGroupingExpressionDescription());
            a.ab("WebGroupingExpression", WebGroupingExpressionDescriptionMetadata.a);
        }
    }
    WebGroupingExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupingExpressionDescriptionMetadata, 'WebGroupingExpressionDescriptionMetadata');
    WebGroupingExpressionDescriptionMetadata.a = null;
    return WebGroupingExpressionDescriptionMetadata;
})();
